==> tms-common-table-0.0.5.tgz: package/src/component/CommonSearch/CommonSearch.jsx <==
import React from 'react';
import styled from 'styled-components';
import { Button } from 'antd';
import { CommonSearchFilter } from './CommonSearchFilter';
import { CommonSearchFullText } from './CommonSearchFullText';
import { CommonSearchForm } from './CommonSearchForm';

export const StyleContainer = styled.section`
    display: flex;
    margin-bottom: 10px;
    align-items: flex-start;
`;

export const CommonSearchRightArea = styled.section`
    margin-left: auto;
    min-width: 300px;
    text-align: right;
    display: flex;
    align-items: center;
    justify-content: flex-end;
    .ant-form-item {
        margin-bottom: 0;
        margin-right: 10px;
    }
`;

export const CommonSearchLeftArea = styled.section`
    display: flex;
    align-items: flex-start;
`;

export const CommonSearchButtonArea = styled(CommonSearchLeftArea)`
    height: 39px;
    align-items: center;
    .ant-btn {
        margin-left: 10px;
        height: 30px;
        border-radius: 0;
    }
`;

export const ExpandButton = styled.a`
    display: block;
    line-height: 40px;
    min-width: 28px;
`;

export class CommonSearch extends React.Component {
    state = {
        formExpand: false,
        formSearchLoading: false
    };

    toggleFormExpand = e => {
        e.preventDefault();
        this.setState(prevState => {
            return {
                formExpand: !prevState.formExpand
            };
        });
    };

    render() {
        const {
            fullTextSearch,
            outerFilter = true,
            onFullTextSearch = () => {},
            onFullTextSearchChange = () => {},
            onFilterColumnCheck = () => {},
            onFilterColumnsReset = () => {},
            onFilterColumnSearch = () => {},
            onFormSearch = () => {},
            onFormReset = () => {},
            filterColumnsSearchText,
            filterColumns,
            columns,
            searchItems,
            form,
            loading
        } = this.props;
        return (
            <StyleContainer>
                {searchItems ? (
                    <>
                        <CommonSearchLeftArea>
                            <CommonSearchForm
                                expand={this.state.formExpand}
                                form={form}
                                searchItems={searchItems}
                                fullTextSearch={fullTextSearch}
                            />
                        </CommonSearchLeftArea>
                        <ExpandButton onClick={this.toggleFormExpand}>
                            {this.state.formExpand ? '收起' : '展开'}
                        </ExpandButton>
                        <CommonSearchButtonArea>
                            <Button
                                type="primary"
                                onClick={() => {
                                    onFormSearch();
                                }}
                                loading={loading}
                            >
                                查询
                            </Button>
                            <Button onClick={onFormReset}>重置</Button>
                        </CommonSearchButtonArea>
                    </>
                ) : null}
                <CommonSearchRightArea>
                    <CommonSearchFullText
                        fullTextSearch={fullTextSearch}
                        onFullTextSearch={onFullTextSearch}
                        onFullTextSearchChange={onFullTextSearchChange}
                    />
                    <CommonSearchFilter
                        outerFilter={outerFilter}
                        columns={columns || []}
                        filterColumns={filterColumns}
                        onReset={onFilterColumnsReset}
                        onFilterColumnCheck={onFilterColumnCheck}
                        onFilterColumnSearch={onFilterColumnSearch}
                        filterColumnsSearchText={filterColumnsSearchText}
                    />
                </CommonSearchRightArea>
            </StyleContainer>
        );
    }
}

==> tms-common-table-0.0.11.tgz: package/src/component/CommonSearch/CommonSearch.jsx <==
import React from 'react';
import styled from 'styled-components';
import { Button } from 'antd';
import { CommonSearchFilter } from './CommonSearchFilter';
import { CommonSearchFullText } from './CommonSearchFullText';
import { CommonSearchForm } from './CommonSearchForm';

export const StyleContainer = styled.section`
    display: flex;
    margin-bottom: 10px;
    align-items: flex-start;
`;

export const CommonSearchRightArea = styled.section`
    margin-left: auto;
    min-width: 300px;
    text-align: right;
    display: flex;
    align-items: center;
    justify-content: flex-end;
    .ant-form-item {
        margin-bottom: 0;
        margin-right: 10px;
    }
`;

export const CommonSearchLeftArea = styled.section`
    display: flex;
    align-items: flex-start;
`;

export const CommonSearchButtonArea = styled(CommonSearchLeftArea)`
    height: 39px;
    align-items: center;
    .ant-btn {
        margin-left: 10px;
        height: 30px;
        border-radius: 0;
    }
`;

export const ExpandButton = styled.a`
    display: block;
    line-height: 40px;
    min-width: 28px;
`;

export class CommonSearch extends React.Component {
    state = {
        formExpand: false ,
        formSearchLoading: false
    };

    toggleFormExpand = e => {
        e.preventDefault();
        console.log(this.state.formExpand);
        this.setState({
            formExpand: !this.state.formExpand
        });
    };

    render() {
        const {
            fullTextSearch ,
            outerFilter = true ,
            onFullTextSearch = () => {} ,
            onFullTextSearchChange = () => {} ,
            onFilterColumnCheck = () => {} ,
            onFilterColumnsReset = () => {} ,
            onFilterColumnSearch = () => {} ,
            onFormSearch = () => {} ,
            onFormReset = () => {} ,
            filterColumnsSearchText ,
            filterColumns ,
            columns ,
            searchItems ,
            form ,
            loading
        } = this.props;
        return (
            <StyleContainer>
                {searchItems ? (
                    <>
                        <CommonSearchLeftArea>
                            <CommonSearchForm
                                expand={this.state.formExpand}
                                form={form}
                                searchItems={searchItems}
                                fullTextSearch={fullTextSearch}
                            />
                        </CommonSearchLeftArea>
                        <ExpandButton onClick={this.toggleFormExpand}>
                            {this.state.formExpand ? '收起' : '展开'}
                        </ExpandButton>
                        <CommonSearchButtonArea>
                            <Button
                                type="primary"
                                onClick={() => {
                                    onFormSearch();
                                }}
                                loading={loading}
                            >
                                查询
                            </Button>
                            <Button onClick={onFormReset}>重置</Button>
                        </CommonSearchButtonArea>
                    </>
                ) : null}
                <CommonSearchRightArea>
                    <CommonSearchFullText
                        fullTextSearch={fullTextSearch}
                        onFullTextSearch={onFullTextSearch}
                        onFullTextSearchChange={onFullTextSearchChange}
                    />
                    <CommonSearchFilter
                        outerFilter={outerFilter}
                        columns={columns || []}
                        filterColumns={filterColumns}
                        onReset={onFilterColumnsReset}
                        onFilterColumnCheck={onFilterColumnCheck}
                        onFilterColumnSearch={onFilterColumnSearch}
                        filterColumnsSearchText={filterColumnsSearchText}
                    />
                </CommonSearchRightArea>
            </StyleContainer>
        );
    }
}
